/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sedona.sql.functions.geohash

import org.apache.sedona.sql.functions.FunctionsHelper
import org.scalatest.funsuite.AnyFunSuite
import org.scalatest.matchers.should.Matchers
import org.scalatest.prop.TableDrivenPropertyChecks

class TestCalculatingGeoHash
    extends AnyFunSuite
    with Matchers
    with TableDrivenPropertyChecks
    with FunctionsHelper {
  for ((statement: String, inputGeometry: String, precision: Int, geoHash: Option[String]) <-
      Fixtures.geometriesToCalculateGeoHash) {
    test("it calculate geohash for " + statement) {
      Fixtures.calculateGeoHash(wktReader.read(inputGeometry), precision) shouldBe geoHash
    }
  }
}
